@@ -7,7 +7,7 @@ def check_if_other_tokens_need_to_be_revoked(user) -> bool:
     return False
 
 
-def handle_gauth(user):
+def handle_gauth(authObj, user):
     return None
 
 
