@@ -54,17 +54,17 @@ def verify_refresh_token(token: str) -> RefreshToken:
         revoked__isnull=True  # A refresh token is revoked if the revoked timestamp is set
     )
     if (
-        # Check if the ip & user agents in payload match those in db
-        token.ip == payload['ip'] and
-        token.userAgent == payload['userAgent'] and
-        # Check if the token has not expired
-        token.issued + JWT_REFRESH_TOKEN_EXPIRATION_DELTA > timezone.now()
+        ENABLE_FINGERPRINTING and not (
+            # Check if the ip & user agents in payload match those in db
+            token.ip == payload['ip'] and
+            token.userAgent == payload['userAgent']
+        )
     ):
-        # Check if the token has not expired
-        if token.issued + JWT_REFRESH_TOKEN_EXPIRATION_DELTA > timezone.now():
-            return token
-        raise AuthError('Refresh token validity expired', code='REFRESH_TOKEN_EXPIRED')
-    raise AuthError('Refresh token payload not matching records', code='INVALID_TOKEN_PAYLOAD')
+        raise AuthError('Refresh token payload not matching records', code='INVALID_TOKEN_PAYLOAD')
+    # Check if the token has not expired
+    if token.issued + JWT_REFRESH_TOKEN_EXPIRATION_DELTA > timezone.now():
+        return token
+    raise AuthError('Refresh token validity expired', code='REFRESH_TOKEN_EXPIRED')
 
 
 def get_refresh_token_from_request(request: HttpRequest) -> RefreshToken:
